# Snake
Clone of Snake game written in Python. <br>

To install run `pip install pysnakepygame` and then run `snake` to play. <br>

Available on PyPI <a href=https://pypi.org/project/pysnakepygame>here</a>.
